@@ -11,10 +11,12 @@ class StartCommand(Command):
         receiver: Receiver,
         setup_repos: Optional[List[str]],
         edit_repos: Optional[List[str]],
+        workers: Optional[List[str]],
     ) -> None:
         self._receiver: Receiver = receiver
         self._setup_repos: Optional[List[str]] = setup_repos
         self._edit_repos: Optional[List[str]] = edit_repos
+        self._workers: Optional[List[str]] = workers
 
     def execute(self) -> None:
         self._receiver.initialize_tmux_server()
@@ -22,3 +24,5 @@ class StartCommand(Command):
             self._receiver.create_parasut_ws_setup(self._setup_repos)
         if self._edit_repos:
             self._receiver.create_parasut_ws_editor(self._edit_repos)
+        if self._workers:
+            self._receiver.create_parasut_ws_worker(self._workers)
