@@ -90,6 +90,15 @@ class Receiver:
             npm_login="npm login",
             npm_publish="npm publish",
             npm_delete_registry="npm config delete registry",
+            git_change_branch_master="git checkout master",
+            git_change_branch_develop="git checkout develop",
+            git_fetch_all="git fetch --all",
+            git_pull_origin_master="git pull origin master",
+            git_pull_origin_develop="git pull origin develop",
+        )
+        self._worker_commands: Dict[str, str] = dict(
+            launch_server_worker="foreman start -m 'worker=1, shoryuken=1, sidekiq_mikro_outbound=1, sidekiq_mikro_outbound=1'",  # noqa: E501
+            launch_e_doc_broker_worker="foreman start -m 'shoryuken=1, sidekiq_inbound=1, sidekiq_outbound=1, sidekiq_send=1, sidekiq_fetch_ubl=1, sidekiq_storage=1, sidekiq_other=1, sidekiq_migrations=1'",  # noqa: E501
         )
         self._server_commands: Dict[str, str] = dict(
             launch_text_editor=self.PARASUT_CLI_TEXT_EDITOR,
@@ -145,7 +154,7 @@ class Receiver:
         self._ui_library_commands: Dict[str, str] = dict(
             launch_text_editor=self.PARASUT_CLI_TEXT_EDITOR,
             choose_yarn_version=f"asdf local yarn {self.UI_LIBRARY_YARN_V}",
-            choose_node_version=f"asdf local yarn {self.UI_LIBRARY_NODE_V}",
+            choose_node_version=f"asdf local nodejs {self.UI_LIBRARY_NODE_V}",
             ember_serve=f"PROJECT_TARGET=phoenix ember s --live-reload-port {self.UI_LIBRARY_EMBER_PORT}",  # noqa: E501
         )
         self._shared_logic_commands: Dict[str, str] = dict(
@@ -239,6 +248,9 @@ class Receiver:
                 self._core_commands["source_asdf"],
                 self._shared_logic_commands["choose_yarn_version"],
                 self._shared_logic_commands["choose_node_version"],
+                self._core_commands["git_change_branch_master"],
+                self._core_commands["git_pull_origin_master"],
+                self._core_commands["git_fetch_all"],
                 self._core_commands["ember_release"],
                 self._core_commands["npm_set_parasut_registry"],
                 self._core_commands["npm_login"],
@@ -267,6 +279,9 @@ class Receiver:
                 self._core_commands["source_asdf"],
                 self._ui_library_commands["choose_yarn_version"],
                 self._ui_library_commands["choose_node_version"],
+                self._core_commands["git_change_branch_develop"],
+                self._core_commands["git_pull_origin_develop"],
+                self._core_commands["git_fetch_all"],
                 self._core_commands["ember_release"],
                 self._core_commands["npm_set_parasut_registry"],
                 self._core_commands["npm_login"],
@@ -321,37 +336,37 @@ class Receiver:
         self._change_directory(base_path)
 
         try:
-            if "server" == repo_name:
+            if repo_name == "server":
                 self._run_process([self._task_run_server], show_output=True)
-            elif "server-sidekiq" == repo_name:
+            elif repo_name == "server-sidekiq":
                 self._run_process([self._task_run_server_sidekiq], show_output=True)
-            elif "billing" == repo_name:
+            elif repo_name == "billing":
                 self._run_process([self._task_run_billing], show_output=True)
-            elif "billing-sidekiq" == repo_name:
+            elif repo_name == "billing-sidekiq":
                 self._run_process([self._task_run_billing_sidekiq], show_output=True)
-            elif "e-doc-broker" == repo_name:
+            elif repo_name == "e-doc-broker":
                 self._run_process([self._task_run_e_doc_broker], show_output=True)
-            elif "e-doc-broker-sidekiq" == repo_name:
+            elif repo_name == "e-doc-broker-sidekiq":
                 self._run_process(
                     [self._task_run_e_doc_broker_sidekiq], show_output=True
                 )
-            elif "post-office" == repo_name:
+            elif repo_name == "post-office":
                 self._run_process([self._task_run_post_office], show_output=True)
-            elif "post-office-sidekiq" == repo_name:
+            elif repo_name == "post-office-sidekiq":
                 self._run_process(
                     [self._task_run_post_office_sidekiq], show_output=True
                 )
-            elif "ubl-validator" == repo_name:
+            elif repo_name == "ubl-validator":
                 self._run_process([self._task_run_ubl_validator], show_output=True)
-            elif "phoenix" == repo_name:
+            elif repo_name == "phoenix":
                 self._run_process([self._task_run_phoenix], show_output=True)
-            elif "shared-logic" == repo_name:
+            elif repo_name == "shared-logic":
                 self._run_process([self._task_run_shared_logic], show_output=True)
-            elif "trinity" == repo_name:
+            elif repo_name == "trinity":
                 self._run_process([self._task_run_trinity], show_output=True)
-            elif "ui-library" == repo_name:
+            elif repo_name == "ui-library":
                 self._run_process([self._task_run_ui_library], show_output=True)
-            elif "client" == repo_name:
+            elif repo_name == "client":
                 self._run_process([self._task_run_client], show_output=True)
         except KeyboardInterrupt:
             pass
@@ -364,9 +379,9 @@ class Receiver:
         self._change_directory(base_path)
 
         try:
-            if "shared-logic" == repo_name:
+            if repo_name == "shared-logic":
                 self._run_process([self._task_release_shared_logic], show_output=True)
-            elif "ui-library" == repo_name:
+            elif repo_name == "ui-library":
                 self._run_process([self._task_release_ui_library], show_output=True)
         except KeyboardInterrupt:
             pass
@@ -391,40 +406,40 @@ class Receiver:
 
         # launch relative repos
         for repo_name in repos:
-            if "server" == repo_name:
+            if repo_name == "server":
                 self._change_directory(f"{self.PARASUT_BASE_DIR}/{self.SERVER_DIR}")
                 self._launch_parasut_server_repo()
-            elif "billing" == repo_name:
+            elif repo_name == "billing":
                 self._change_directory(f"{self.PARASUT_BASE_DIR}/{self.BILLING_DIR}")
                 self._launch_parasut_billing_repo()
-            elif "e-doc-broker" == repo_name:
+            elif repo_name == "e-doc-broker":
                 self._change_directory(
                     f"{self.PARASUT_BASE_DIR}/{self.E_DOC_BROKER_DIR}"
                 )
                 self._launch_parasut_e_doc_broker_repo()
-            elif "post-office" == repo_name:
+            elif repo_name == "post-office":
                 self._change_directory(
                     f"{self.PARASUT_BASE_DIR}/{self.POST_OFFICE_DIR}"
                 )
                 self._launch_parasut_post_office_repo()
-            elif "ubl-validator" == repo_name:
+            elif repo_name == "ubl-validator":
                 self._change_directory(
                     f"{self.PARASUT_BASE_DIR}/{self.UBL_VALIDATOR_DIR}"
                 )
                 self._launch_parasut_ubl_validator_repo()
-            elif "phoenix" == repo_name:
+            elif repo_name == "phoenix":
                 self._change_directory(f"{self.PARASUT_BASE_DIR}/{self.PHOENIX_DIR}")
                 self._launch_parasut_phoenix_repo()
-            elif "client" == repo_name:
+            elif repo_name == "client":
                 self._change_directory(f"{self.PARASUT_BASE_DIR}/{self.CLIENT_DIR}")
                 self._launch_parasut_client_repo()
-            elif "trinity" == repo_name:
+            elif repo_name == "trinity":
                 self._change_directory(f"{self.PARASUT_BASE_DIR}/{self.TRINITY_DIR}")
                 self._launch_parasut_trinity_repo()
-            elif "ui-library" == repo_name:
+            elif repo_name == "ui-library":
                 self._change_directory(f"{self.PARASUT_BASE_DIR}/{self.UI_LIBRARY_DIR}")
                 self._launch_parasut_ui_library_repo()
-            elif "shared-logic" == repo_name:
+            elif repo_name == "shared-logic":
                 self._change_directory(
                     f"{self.PARASUT_BASE_DIR}/{self.SHARED_LOGIC_DIR}"
                 )
@@ -454,49 +469,84 @@ class Receiver:
 
         # launch relative repos
         for repo_name in repos:
-            if "server" == repo_name:
+            if repo_name == "server":
                 self._change_directory(f"{self.PARASUT_BASE_DIR}/{self.SERVER_DIR}")
                 self._launch_parasut_server_editor()
-            elif "billing" == repo_name:
+            elif repo_name == "billing":
                 self._change_directory(f"{self.PARASUT_BASE_DIR}/{self.BILLING_DIR}")
                 self._launch_parasut_billing_editor()
-            elif "e-doc-broker" == repo_name:
+            elif repo_name == "e-doc-broker":
                 self._change_directory(
                     f"{self.PARASUT_BASE_DIR}/{self.E_DOC_BROKER_DIR}"
                 )
                 self._launch_parasut_e_doc_broker_editor()
-            elif "post-office" == repo_name:
+            elif repo_name == "post-office":
                 self._change_directory(
                     f"{self.PARASUT_BASE_DIR}/{self.POST_OFFICE_DIR}"
                 )
                 self._launch_parasut_post_office_editor()
-            elif "ubl-validator" == repo_name:
+            elif repo_name == "ubl-validator":
                 self._change_directory(
                     f"{self.PARASUT_BASE_DIR}/{self.UBL_VALIDATOR_DIR}"
                 )
                 self._launch_parasut_ubl_validator_editor()
-            elif "phoenix" == repo_name:
+            elif repo_name == "phoenix":
                 self._change_directory(f"{self.PARASUT_BASE_DIR}/{self.PHOENIX_DIR}")
                 self._launch_parasut_phoenix_editor()
-            elif "client" == repo_name:
+            elif repo_name == "client":
                 self._change_directory(f"{self.PARASUT_BASE_DIR}/{self.CLIENT_DIR}")
                 self._launch_parasut_client_editor()
-            elif "trinity" == repo_name:
+            elif repo_name == "trinity":
                 self._change_directory(f"{self.PARASUT_BASE_DIR}/{self.TRINITY_DIR}")
                 self._launch_parasut_trinity_editor()
-            elif "ui-library" == repo_name:
+            elif repo_name == "ui-library":
                 self._change_directory(f"{self.PARASUT_BASE_DIR}/{self.UI_LIBRARY_DIR}")
                 self._launch_parasut_ui_library_editor()
-            elif "shared-logic" == repo_name:
+            elif repo_name == "shared-logic":
                 self._change_directory(
                     f"{self.PARASUT_BASE_DIR}/{self.SHARED_LOGIC_DIR}"
                 )
                 self._launch_parasut_shared_logic_editor()
+
         # kill the first empty window if new session initialized
         if not session:
             self._tmux_session_parasut_ws_editor.select_window(1).kill_window()
         self._tmux_session_parasut_ws_editor.select_window(1)
 
+    def create_parasut_ws_worker(self, workers: List[str]) -> None:
+        session: Optional[Session]
+
+        # get or create session
+        try:
+            session = self._tmux_server.find_where(
+                {"session_name": "parasut-ws-worker"}
+            )
+        except LibTmuxException:
+            session = None
+        finally:
+            if session:
+                self._tmux_session_parasut_ws_worker = session
+            else:
+                self._tmux_session_parasut_ws_worker = self._tmux_server.new_session(
+                    session_name="parasut-ws-worker", kill_session=True, attach=False
+                )
+
+        # launch relative repos
+        for worker in workers:
+            if worker == "server-worker":
+                self._change_directory(f"{self.PARASUT_BASE_DIR}/{self.SERVER_DIR}")
+                self._launch_parasut_server_worker()
+            elif worker == "e-doc-broker-worker":
+                self._change_directory(
+                    f"{self.PARASUT_BASE_DIR}/{self.E_DOC_BROKER_DIR}"
+                )
+                self._launch_parasut_e_doc_broker_worker()
+
+        # kill the first empty window if new session initialized
+        if not session:
+            self._tmux_session_parasut_ws_worker.select_window(1).kill_window()
+        self._tmux_session_parasut_ws_worker.select_window(1)
+
     def switch_server_rails_frontend(self, target_repo: str, show_output: bool) -> None:
         server_repo: str = f"{self.PARASUT_BASE_DIR}/{self.SERVER_DIR}"
 
@@ -866,6 +916,21 @@ class Receiver:
             )
         )
 
+    def _launch_parasut_server_worker(self) -> None:
+        server_worker_window: Window = self._tmux_session_parasut_ws_worker.new_window(
+            attach=False, window_name="server_worker"
+        )
+        server_worker_pane: Pane = server_worker_window.attached_pane
+
+        server_worker_pane.send_keys(
+            " && ".join(
+                [
+                    self._server_commands["choose_ruby_version"],
+                    self._worker_commands["launch_server_worker"],
+                ]
+            )
+        )
+
     def _launch_parasut_billing_repo(self) -> None:
         billing_window: Window = self._tmux_session_parasut_ws_setup.new_window(
             attach=False, window_name="billing"
@@ -950,6 +1015,23 @@ class Receiver:
             )
         )
 
+    def _launch_parasut_e_doc_broker_worker(self) -> None:
+        e_doc_broker_worker_window: Window = (
+            self._tmux_session_parasut_ws_worker.new_window(
+                attach=False, window_name="e_doc_broker_worker"
+            )
+        )
+        e_doc_broker_worker_pane: Pane = e_doc_broker_worker_window.attached_pane
+
+        e_doc_broker_worker_pane.send_keys(
+            " && ".join(
+                [
+                    self._e_doc_broker_commands["choose_ruby_version"],
+                    self._worker_commands["launch_e_doc_broker_worker"],
+                ]
+            )
+        )
+
     def _launch_parasut_post_office_repo(self) -> None:
         post_office_window: Window = self._tmux_session_parasut_ws_setup.new_window(
             attach=False, window_name="post_office"
@@ -1030,8 +1112,8 @@ class Receiver:
         phoenix_pane.send_keys(
             " && ".join(
                 [
-                    self._phoenix_commands["choose_node_version"],
                     self._phoenix_commands["choose_yarn_version"],
+                    self._phoenix_commands["choose_node_version"],
                     self._phoenix_commands["ember_serve"],
                 ]
             )
@@ -1046,8 +1128,8 @@ class Receiver:
         phoenix_pane.send_keys(
             " && ".join(
                 [
-                    self._phoenix_commands["choose_node_version"],
                     self._phoenix_commands["choose_yarn_version"],
+                    self._phoenix_commands["choose_node_version"],
                     self._phoenix_commands["launch_text_editor"],
                 ]
             )
@@ -1062,8 +1144,8 @@ class Receiver:
         client_pane.send_keys(
             " && ".join(
                 [
-                    self._client_commands["choose_node_version"],
                     self._client_commands["choose_yarn_version"],
+                    self._client_commands["choose_node_version"],
                     self._client_commands["ember_serve"],
                 ]
             )
@@ -1078,8 +1160,8 @@ class Receiver:
         client_pane.send_keys(
             " && ".join(
                 [
-                    self._client_commands["choose_node_version"],
                     self._client_commands["choose_yarn_version"],
+                    self._client_commands["choose_node_version"],
                     self._client_commands["launch_text_editor"],
                 ]
             )
@@ -1094,8 +1176,8 @@ class Receiver:
         trinity_pane.send_keys(
             " && ".join(
                 [
-                    self._trinity_commands["choose_node_version"],
                     self._trinity_commands["choose_yarn_version"],
+                    self._trinity_commands["choose_node_version"],
                     self._trinity_commands["ember_serve"],
                 ]
             )
@@ -1110,8 +1192,8 @@ class Receiver:
         trinity_pane.send_keys(
             " && ".join(
                 [
-                    self._trinity_commands["choose_node_version"],
                     self._trinity_commands["choose_yarn_version"],
+                    self._trinity_commands["choose_node_version"],
                     self._trinity_commands["launch_text_editor"],
                 ]
             )
@@ -1126,8 +1208,8 @@ class Receiver:
         ui_library_pane.send_keys(
             " && ".join(
                 [
-                    self._ui_library_commands["choose_node_version"],
                     self._ui_library_commands["choose_yarn_version"],
+                    self._ui_library_commands["choose_node_version"],
                     self._ui_library_commands["ember_serve"],
                 ]
             )
@@ -1142,8 +1224,8 @@ class Receiver:
         ui_library_pane.send_keys(
             " && ".join(
                 [
-                    self._ui_library_commands["choose_node_version"],
                     self._ui_library_commands["choose_yarn_version"],
+                    self._ui_library_commands["choose_node_version"],
                     self._ui_library_commands["launch_text_editor"],
                 ]
             )
@@ -1158,8 +1240,8 @@ class Receiver:
         shared_logic_pane.send_keys(
             " && ".join(
                 [
-                    self._shared_logic_commands["choose_node_version"],
                     self._shared_logic_commands["choose_yarn_version"],
+                    self._shared_logic_commands["choose_node_version"],
                     self._shared_logic_commands["ember_serve"],
                 ]
             )
@@ -1174,8 +1256,8 @@ class Receiver:
         shared_logic_pane.send_keys(
             " && ".join(
                 [
-                    self._shared_logic_commands["choose_node_version"],
                     self._shared_logic_commands["choose_yarn_version"],
+                    self._shared_logic_commands["choose_node_version"],
                     self._shared_logic_commands["launch_text_editor"],
                 ]
             )
